==> GNUMail-1.0.3.tar.gz: GNUMail/Filter.h <==
/*
**  Filter.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import <AppKit/AppKit.h>

// criteria source
#define NONE     0
#define TO       1
#define CC       2
#define TO_OR_CC 3
#define SUBJECT  4
#define FROM     5
#define EXPERT   6

// external program operation
#define AFTER_CRITERIA  1
#define BEFORE_CRITERIA 2

// criteria condition
#define AND 1
#define OR  2

// criteria find operations
#define CONTAINS           1
#define IS_EQUAL           2
#define HAS_PREFIX         3
#define HAS_SUFFIX         4
#define MATCH_REGEXP       5
#define IS_IN_ADDRESS_BOOK 6

// actions
#define SET_COLOR                  1
#define TRANSFER_TO_FOLDER         2
#define BOUNCE_OR_FORWARD_OR_REPLY 3
#define DELETE                     4

// email operations
#define BOUNCE  1
#define FORWARD 2
#define REPLY   3

// filter type
#define TYPE_INCOMING 1
#define TYPE_OUTGOING 2


@interface Filter: NSObject <NSCoding, NSCopying>
{
  BOOL isActive;
  NSString *description;
  
  int type;

  BOOL useExternalProgram;
  NSString *externalProgramName;
  int externalProgramOperation;

  NSMutableArray *allCriterias;

  int action;
  NSColor *actionColor;
  NSString *actionFolderName;
  int actionEMailOperation;
  NSString *actionEMailString;
  NSString *actionMessageString;
}

//
//
//
- (id) init;
- (void) dealloc;

//
// Coding protocol
//
- (void) encodeWithCoder: (NSCoder *) theCoder;
- (id) initWithCoder: (NSCoder *) theCoder;


//
// NSCopying protocol
//
- (id) copyWithZone: (NSZone *) zone;

//
// access/mutation methods
//
- (BOOL) isActive;
- (void) setIsActive: (BOOL) theBOOL;

- (NSString *) description;
- (void) setDescription: (NSString *) theDescription;

- (int) type;
- (void) setType: (int) theType;

- (BOOL) useExternalProgram;
- (void) setUseExternalProgram: (BOOL) theBOOL;

- (NSString *) externalProgramName;
- (void) setExternalProgramName: (NSString *) theExternalProgramName;

- (int) externalProgramOperation;
- (void) setExternalProgramOperation: (int) theExternalProgramOperation;

- (NSArray *) allCriterias;
- (void) setCriterias: (NSArray *) theCriterias;

- (int) action;
- (void) setAction: (int) theAction;

- (NSColor *) actionColor;
- (void) setActionColor: (NSColor *) theActionColor;

- (NSString *) actionFolderName;
- (void) setActionFolderName: (NSString *) theActionFolderName; 

- (int) actionEMailOperation;
- (void) setActionEMailOperation: (int) theActionEMailOperation;

- (NSString *) actionEMailString;
- (void) setActionEMailString: (NSString *) theActionEMailString;

- (NSString *) actionMessageString;
- (void) setActionMessageString: (NSString *) theActionMessageString;

@end


//
//
//
@interface FilterCriteria : NSObject <NSCoding, NSCopying>
{
  int criteriaCondition;
  int criteriaSource;
  NSArray *criteriaHeaders;
  int criteriaFindOperation;
  NSString *criteriaString;
}

//
// Coding protocol
//
- (void) encodeWithCoder: (NSCoder *) theCoder;
- (id) initWithCoder: (NSCoder *) theCoder;


//
// NSCopying protocol
//
- (id) copyWithZone: (NSZone *) zone;


//
// access / mutation methods
//
- (int) criteriaCondition;
- (void) setCriteriaCondition: (int) theCriteriaCondition;

- (int) criteriaSource;
- (void) setCriteriaSource: (int) theCriteriaSource;

- (NSArray *) criteriaHeaders;
- (void) setCriteriaHeaders: (NSArray *) theCriteriaHeaders;

- (int) criteriaFindOperation;
- (void) setCriteriaFindOperation: (int) theCriteriaFindOperation;

- (NSString *) criteriaString;
- (void) setCriteriaString: (NSString *) theCriteriaString;


@end

==> GNUMail-1.2.0pre1.tar.gz: GNUMail/Filter.h <==
/*
**  Filter.h
**
**  Copyright (c) 2001-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_Filter
#define _GNUMail_H_Filter

#import <AppKit/AppKit.h>

// criteria source
#define NONE     0
#define TO       1
#define CC       2
#define TO_OR_CC 3
#define SUBJECT  4
#define FROM     5
#define EXPERT   6

// External program operation
#define AFTER_CRITERIA  1
#define BEFORE_CRITERIA 2

// Criteria condition
#define AND 1
#define OR  2

// Criteria find operations
#define CONTAINS                 1
#define IS_EQUAL                 2
#define HAS_PREFIX               3
#define HAS_SUFFIX               4
#define MATCH_REGEXP             5
#define IS_IN_ADDRESS_BOOK       6
#define IS_IN_ADDRESS_BOOK_GROUP 7

// Actions
#define SET_COLOR                  1
#define TRANSFER_TO_FOLDER         2
#define BOUNCE_OR_FORWARD_OR_REPLY 3
#define DELETE                     4
#define PLAY_SOUND                 5

// E-Mail operations
#define BOUNCE  1
#define FORWARD 2
#define REPLY   3

// Filter type
#define TYPE_INCOMING 1
#define TYPE_OUTGOING 2


@interface Filter: NSObject <NSCoding, NSCopying>
{
  @private
    BOOL _isActive;
    NSString *_description;
  
    int _type;

    BOOL _useExternalProgram;
    NSString *_externalProgramName;
    int _externalProgramOperation;

    NSMutableArray *_allCriterias;

    int _action;
    NSColor *_actionColor;
    NSString *_actionFolderName;
    int _actionEMailOperation;
    NSString *_actionEMailString;
    NSString *_actionMessageString;

    NSString *_pathToSound;
}

//
// access/mutation methods
//
- (BOOL) isActive;
- (void) setIsActive: (BOOL) theBOOL;

- (NSString *) description;
- (void) setDescription: (NSString *) theDescription;

- (int) type;
- (void) setType: (int) theType;

- (BOOL) useExternalProgram;
- (void) setUseExternalProgram: (BOOL) theBOOL;

- (NSString *) externalProgramName;
- (void) setExternalProgramName: (NSString *) theExternalProgramName;

- (int) externalProgramOperation;
- (void) setExternalProgramOperation: (int) theExternalProgramOperation;

- (NSArray *) allCriterias;
- (void) setCriterias: (NSArray *) theCriterias;

- (int) action;
- (void) setAction: (int) theAction;

- (NSColor *) actionColor;
- (void) setActionColor: (NSColor *) theActionColor;

- (NSString *) actionFolderName;
- (void) setActionFolderName: (NSString *) theActionFolderName; 

- (int) actionEMailOperation;
- (void) setActionEMailOperation: (int) theActionEMailOperation;

- (NSString *) actionEMailString;
- (void) setActionEMailString: (NSString *) theActionEMailString;

- (NSString *) actionMessageString;
- (void) setActionMessageString: (NSString *) theActionMessageString;

- (NSString *) pathToSound;
- (void) setPathToSound: (NSString *) thePath;

@end


//
//
//
@interface FilterCriteria : NSObject <NSCoding, NSCopying>
{
  @private
    NSArray *_criteriaHeaders;
    NSString *_criteriaString;

    int _criteriaFindOperation;
    int _criteriaCondition;
    int _criteriaSource;
}

//
// access / mutation methods
//
- (int) criteriaCondition;
- (void) setCriteriaCondition: (int) theCriteriaCondition;

- (int) criteriaSource;
- (void) setCriteriaSource: (int) theCriteriaSource;

- (NSArray *) criteriaHeaders;
- (void) setCriteriaHeaders: (NSArray *) theCriteriaHeaders;

- (int) criteriaFindOperation;
- (void) setCriteriaFindOperation: (int) theCriteriaFindOperation;

- (NSString *) criteriaString;
- (void) setCriteriaString: (NSString *) theCriteriaString;

@end

#endif // _GNUMail_H_Filter
